@@ -22,12 +22,12 @@
 import os, sys
 
 
-VERSION = "0.35.7"
+VERSION = "0.35.8"
 APP_NAME = "cherrytree"
 NEWER_VERSION_URL = "http://www.giuspen.com/software/version_cherrytree"
 if sys.platform.startswith("win"):
     IS_WIN_OS = True
-    SZA_PATH = os.path.join(SHARE_PATH, "7za.exe")
+    SZA_PATH = '"'+os.path.join(SHARE_PATH, "7za.exe")+'"'
     if SHARE_PATH:
         EXE_DIR = SHARE_PATH
         os.chdir(EXE_DIR)
@@ -130,6 +130,7 @@ NODES_ICONS = {0:'cherry_red', 1:'cherry_blue', 2:'cherry_orange', 3:'cherry_cya
 CODE_ICONS = {"python": 'cherry_green', "sh":'cherry_purple',
               "c":'cherry_black', "cpp":'cherry_black', "chdr":'cherry_black'}
 
+MIN_CT_DOC_SIZE = 10
 MAX_FILE_NAME_LEN = 150
 WHITE_SPACE_BETW_PIXB_AND_TEXT = 3
 GRID_SLIP_OFFSET = 3
